================================
``psyclone.psyir.nodes.ifblock``
================================

.. automodule:: psyclone.psyir.nodes.ifblock

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.ifblock
